==> apemandocker-1.1.1.tgz: package/test/apemandocker_test.js <==
/**
 * Test case for apemandocker.
 * Runs with mocha.
 */
"use strict";

const Apemandocker = require('../lib/apemandocker.js'),
    assert = require('assert');

describe('apemandocker', () => {

    let apemandocker = new Apemandocker({}),
        source = `${__dirname}/../doc/mocks/mock-images/node`,
        image = 'testing-apemandocker-01',
        container = 'testing-apemandocker-01-container-01';

    before((done) => {
        done();
    });

    after((done) => {
        done();
    });

    it('Build an image.', (done) => {
        apemandocker.buildImage(source, {
            tag: image
        }, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Build list images.', (done) => {
        apemandocker.listImages({
        }, (err, images) => {
            assert.ifError(err);
            console.log(images);
            done();
        });
    });

    it('Create a container.', (done) => {
        apemandocker.createContainer(image, {
            name: container
        }, (err) => {
            assert.ifError(err);
            done();
        });
    });


    it('Start a container.', (done) => {
        apemandocker.startContainer(container, {}, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('List containers.', (done) => {
        apemandocker.listContainers({
            all: true
        }, (err, results) => {
            assert.ifError(err);
            assert.ok(results);
            done();
        });
    });

    it('Stop a container.', (done) => {
        apemandocker.stopContainer(container, {}, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Remove a container.', (done) => {
        apemandocker.removeContainer(container, {}, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Remove an image.', (done) => {
        apemandocker.removeImage(image, {
            force: true
        }, (err) => {
            assert.ifError(err);
            done();
        });
    });
});

==> apemandocker-1.2.2.tgz: package/test/apemandocker_test.js <==
/**
 * Test case for apemandocker.
 * Runs with mocha.
 */
"use strict";

const Apemandocker = require('../lib/apemandocker.js'),
    assert = require('assert');

describe('apemandocker', () => {

    let apemandocker = new Apemandocker({}),
        source = `${__dirname}/../doc/mocks/mock-images/node`,
        image = 'testing-apemandocker-01',
        container = 'testing-apemandocker-01-container-01',
        network = 'test-apemandocker-nw-01';

    before((done) => {
        done();
    });

    after((done) => {
        done();
    });

    it('Build an image.', (done) => {
        apemandocker.buildImage(source, {
            tag: image
        }, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Build list images.', (done) => {
        apemandocker.listImages({}, (err, images) => {
            assert.ifError(err);
            console.log(images);
            done();
        });
    });

    it('Create a container.', (done) => {
        apemandocker.createContainer(image, {
            name: container
        }, (err) => {
            assert.ifError(err);
            done();
        });
    });


    it('Start a container.', (done) => {
        apemandocker.startContainer(container, {}, (err) => {
            assert.ifError(err);
            process.nextTick(()=> {
                done();
            });
        });
    });

    it('Check the container running.', (done) => {
        apemandocker.isContainerRunning(container, (running) => {
            assert.equal(running, true);
            done();
        });
    });

    it('List containers.', (done) => {
        apemandocker.listContainers({
            all: true
        }, (err, results) => {
            assert.ifError(err);
            assert.ok(results);
            done();
        });
    });

    it('Terminal with container.', (done) => {
        let terminal = apemandocker.terminal(container);
        setTimeout(()=>{
            terminal.kill(0);
            done();
        }, 1000);
    });

    it('Stop a container.', (done) => {
        apemandocker.stopContainer(container, {}, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Remove a container.', (done) => {
        apemandocker.removeContainer(container, {}, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Remove an image.', (done) => {
        apemandocker.removeImage(image, {
            force: true
        }, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Create network.', (done) => {
        apemandocker.createNetwork(network,{

        }, (err) => {
            assert.ifError(err);
            done();
        })
    });

    it('List network.', (done) => {
        apemandocker.listNetwork({

        }, (err, result) => {
            assert.ifError(err);
            assert.ok(result);
            done();
        })
    });

    it('Remove network.', (done) => {
        apemandocker.removeNetwork(network,{
        }, (err) => {
            assert.ifError(err);
            done();
        })
    });

});
